pm4py.algo.transformation.ocel package
======================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.transformation.ocel.features
   pm4py.algo.transformation.ocel.graphs
   pm4py.algo.transformation.ocel.split_ocel

Module contents
---------------

.. automodule:: pm4py.algo.transformation.ocel
   :members:
   :undoc-members:
   :show-inheritance:
